==> ejc-purchasingmanagement-impl-3.0.0-20220903.162409-208-sources.jar: com/ejianc/business/purchasingmanagement/vo/SupplierinvoicedetialVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 供应商发票管理明细
 * 
 * @author generator
 * 
 */
public class SupplierinvoicedetialVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long supplierinvoiceId; // 主表ID
    private String billCode; // 供应商付款单编号
    private Date receivablesDate; // 记账日期
    private BigDecimal invoiceMoney; // 应开金额
    private BigDecimal receivedMoney; // 本单已开金额
    private BigDecimal otherReceivedMoney; // 其他单已开金额
    private BigDecimal uncollectedMoney; // 未收金额
    private BigDecimal distributionMoney; // 分配金额
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long materialacceptanceId; // 供应商付款单id
    private Long materialId; // 原材料id
    private String materialName; // 原材料名称
    

    public Long getSupplierinvoiceId() {
        return supplierinvoiceId;
    }

    public void setSupplierinvoiceId(Long supplierinvoiceId) {
        this.supplierinvoiceId = supplierinvoiceId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getReceivablesDate() {
        return receivablesDate;
    }

    public void setReceivablesDate(Date receivablesDate) {
        this.receivablesDate = receivablesDate;
    }
    public BigDecimal getInvoiceMoney() {
        return invoiceMoney;
    }

    public void setInvoiceMoney(BigDecimal invoiceMoney) {
        this.invoiceMoney = invoiceMoney;
    }
    public BigDecimal getReceivedMoney() {
        return receivedMoney;
    }

    public void setReceivedMoney(BigDecimal receivedMoney) {
        this.receivedMoney = receivedMoney;
    }
    public BigDecimal getOtherReceivedMoney() {
        return otherReceivedMoney;
    }

    public void setOtherReceivedMoney(BigDecimal otherReceivedMoney) {
        this.otherReceivedMoney = otherReceivedMoney;
    }
    public BigDecimal getUncollectedMoney() {
        return uncollectedMoney;
    }

    public void setUncollectedMoney(BigDecimal uncollectedMoney) {
        this.uncollectedMoney = uncollectedMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
}

==> ejc-purchasingmanagement-impl-3.0.0-20221017.091328-230-sources.jar: com/ejianc/business/purchasingmanagement/vo/SupplierinvoicedetialVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 供应商发票管理明细
 * 
 * @author generator
 * 
 */
public class SupplierinvoicedetialVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long supplierinvoiceId; // 主表ID
    private String billCode; // 供应商付款单编号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date receivablesDate; // 记账日期
    private BigDecimal invoiceMoney; // 应开金额
    private BigDecimal receivedMoney; // 本单已开金额
    private BigDecimal otherReceivedMoney; // 其他单已开金额
    private BigDecimal uncollectedMoney; // 未收金额
    private BigDecimal distributionMoney; // 分配金额
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long materialacceptanceId; // 供应商付款单id
    private Long materialId; // 原材料id
    private String materialName; // 原材料名称
    

    public Long getSupplierinvoiceId() {
        return supplierinvoiceId;
    }

    public void setSupplierinvoiceId(Long supplierinvoiceId) {
        this.supplierinvoiceId = supplierinvoiceId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getReceivablesDate() {
        return receivablesDate;
    }

    public void setReceivablesDate(Date receivablesDate) {
        this.receivablesDate = receivablesDate;
    }
    public BigDecimal getInvoiceMoney() {
        return invoiceMoney;
    }

    public void setInvoiceMoney(BigDecimal invoiceMoney) {
        this.invoiceMoney = invoiceMoney;
    }
    public BigDecimal getReceivedMoney() {
        return receivedMoney;
    }

    public void setReceivedMoney(BigDecimal receivedMoney) {
        this.receivedMoney = receivedMoney;
    }
    public BigDecimal getOtherReceivedMoney() {
        return otherReceivedMoney;
    }

    public void setOtherReceivedMoney(BigDecimal otherReceivedMoney) {
        this.otherReceivedMoney = otherReceivedMoney;
    }
    public BigDecimal getUncollectedMoney() {
        return uncollectedMoney;
    }

    public void setUncollectedMoney(BigDecimal uncollectedMoney) {
        this.uncollectedMoney = uncollectedMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
}
